@@ -1,5 +1,5 @@
 package Moose::Meta::TypeConstraint;
-our $VERSION = '2.1600';
+our $VERSION = '2.1603';
 
 use strict;
 use warnings;
@@ -231,7 +231,8 @@ sub get_message {
 sub equals {
     my ( $self, $type_or_name ) = @_;
 
-    my $other = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $other = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $other;
 
     return 1 if $self == $other;
 
@@ -250,7 +251,8 @@ sub equals {
 sub is_a_type_of {
     my ($self, $type_or_name) = @_;
 
-    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $type;
 
     ($self->equals($type) || $self->is_subtype_of($type));
 }
@@ -258,7 +260,8 @@ sub is_a_type_of {
 sub is_subtype_of {
     my ($self, $type_or_name) = @_;
 
-    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $type;
 
     my $current = $self;
 
@@ -375,7 +378,7 @@ Moose::Meta::TypeConstraint - The Moose Type Constraint metaclass
 
 =head1 VERSION
 
-version 2.1600
+version 2.1603
 
 =head1 DESCRIPTION
 
